@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import List, Optional
 
 from pydantic import BaseSettings, validator
 from pydantic.fields import ModelField
@@ -16,6 +16,12 @@ class Config(BaseSettings):
     haruka_dynamic_interval: int = 0
     haruka_dynamic_at: bool = False
     haruka_screenshot_style: str = "mobile"
+    haruka_dynamic_timeout: int = 10
+    haruka_dynamic_font_source: str = "system"
+    haruka_dynamic_font: Optional[str] = "Noto Sans CJK SC"
+    haruka_command_prefix: str = ""
+    # 频道管理员身份组
+    haruka_guild_admin_roles: List[str] = ["频道主", "管理员"]
 
     @validator("haruka_interval", "haruka_live_interval", "haruka_dynamic_interval")
     def non_negative(cls, v: int, field: ModelField):
