@@ -10,7 +10,7 @@ from tortoise.connection import connections
 
 from ..utils import get_path
 from ..version import VERSION as HBVERSION
-from .models import Group, Sub, User, Version
+from .models import Group, Guild, Sub, User, Version
 
 uid_list = {"live": {"list": [], "index": 0}, "dynamic": {"list": [], "index": 0}}
 dynamic_offset = {}
@@ -22,12 +22,24 @@ class DB:
     @classmethod
     async def init(cls):
         """初始化数据库"""
-        from . import models  # noqa: F401
+        config = {
+            "connections": {
+                # "haruka_bot": {
+                #     "engine": "tortoise.backends.sqlite",
+                #     "credentials": {"file_path": get_path("data.sqlite3")},
+                # },
+                "haruka_bot": f"sqlite://{get_path('data.sqlite3')}"
+            },
+            "apps": {
+                "haruka_bot_app": {
+                    "models": ["haruka_bot.database.models"],
+                    "default_connection": "haruka_bot",
+                }
+            },
+        }
+
+        await Tortoise.init(config)
 
-        await Tortoise.init(
-            db_url=f"sqlite://{get_path('data.sqlite3')}",
-            modules={"models": [locals()["models"]]},
-        )
         await Tortoise.generate_schemas()
         await cls.migrate()
         await cls.update_uid_list()
@@ -73,7 +85,7 @@ class DB:
         return await Group.get(**kwargs).first()
 
     @classmethod
-    async def get_admin(cls, group_id) -> bool:
+    async def get_group_admin(cls, group_id) -> bool:
         """获取指定群权限状态"""
         group = await cls.get_group(id=group_id)
         if not group:
@@ -81,11 +93,34 @@ class DB:
             return True
         return bool(group.admin)
 
+    @classmethod
+    async def get_guild_admin(cls, guild_id, channel_id) -> bool:
+        """获取指定频道权限状态"""
+        guild = await cls.get_guild(guild_id=guild_id, channel_id=channel_id)
+        if not guild:
+            # TODO 自定义默认状态
+            return True
+        return bool(guild.admin)
+
     @classmethod
     async def add_group(cls, **kwargs):
         """创建群设置"""
         return await Group.add(**kwargs)
 
+    @classmethod
+    async def add_guild(cls, **kwargs):
+        """创建频道设置"""
+        return await Guild.add(**kwargs)
+
+    @classmethod
+    async def delete_guild(cls, id) -> bool:
+        """删除子频道设置"""
+        if await cls.get_sub(type="guild", type_id=id):
+            # 当前频道还有订阅，不能删除
+            return False
+        await Guild.delete(id=id)
+        return True
+
     @classmethod
     async def delete_group(cls, id) -> bool:
         """删除群设置"""
@@ -97,10 +132,31 @@ class DB:
 
     @classmethod
     async def set_permission(cls, id, switch):
-        """设置指定位置权限"""
+        """设置指定群组权限"""
         if not await cls.add_group(id=id, admin=switch):
             await Group.update({"id": id}, admin=switch)
 
+    @classmethod
+    async def set_guild_permission(cls, guild_id, channel_id, switch):
+        """设置指定频道权限"""
+        if not await cls.add_guild(
+            guild_id=guild_id, channel_id=channel_id, admin=switch
+        ):
+            await Guild.update(
+                {"guild_id": guild_id, "channel_id": channel_id}, admin=switch
+            )
+
+    @classmethod
+    async def get_guild(cls, **kwargs):
+        """获取频道设置"""
+        return await Guild.get(**kwargs).first()
+
+    @classmethod
+    async def get_guild_type_id(cls, guild_id, channel_id) -> Optional[int]:
+        """获取频道订阅 ID"""
+        guild = await Guild.get(guild_id=guild_id, channel_id=channel_id).first()
+        return guild.id if guild else None
+
     @classmethod
     async def get_sub(cls, **kwargs):
         """获取指定位置的订阅信息"""
@@ -143,7 +199,7 @@ class DB:
 
     @classmethod
     async def delete_sub_list(cls, type, type_id):
-        "删除指定位置的推送列表"
+        """删除指定位置的推送列表"""
         async for sub in Sub.get(type=type, type_id=type_id):
             await cls.delete_sub(uid=sub.uid, type=sub.type, type_id=sub.type_id)
         await cls.update_uid_list()
